@@ -332,6 +332,62 @@ class FitInterferometer(FitDataset):
     def visibilities(self) -> np.ndarray:
         return self.data
 
+    @property
+    def signal_to_noise_map(self) -> np.ndarray:
+        """The signal-to-noise_map of the dataset and noise-map which are fitted."""
+        signal_to_noise_map_real = np.divide(
+            np.real(self.data), np.real(self.noise_map)
+        )
+        signal_to_noise_map_real[signal_to_noise_map_real < 0] = 0.0
+        signal_to_noise_map_imag = np.divide(
+            np.imag(self.data), np.imag(self.noise_map)
+        )
+        signal_to_noise_map_imag[signal_to_noise_map_imag < 0] = 0.0
+
+        return signal_to_noise_map_real + 1.0j * signal_to_noise_map_imag
+
     @property
     def model_visibilities(self) -> np.ndarray:
         return self.model_data
+
+    @property
+    def normalized_residual_map(self) -> np.ndarray:
+        """
+        Returns the normalized residual-map between the masked dataset and model data, where:
+
+        Normalized_Residual = (Data - Model_Data) / Noise
+        """
+        return fit_util.normalized_residual_map_complex_with_mask_from(
+            residual_map=self.residual_map, noise_map=self.noise_map, mask=self.mask
+        )
+
+    @property
+    def chi_squared_map(self) -> np.ndarray:
+        """
+        Returns the chi-squared-map between the residual-map and noise-map, where:
+
+        Chi_Squared = ((Residuals) / (Noise)) ** 2.0 = ((Data - Model)**2.0)/(Variances)
+        """
+        return fit_util.chi_squared_map_complex_with_mask_from(
+            residual_map=self.residual_map, noise_map=self.noise_map, mask=self.mask
+        )
+
+    @property
+    def chi_squared(self) -> float:
+        """
+        Returns the chi-squared terms of the model data's fit to an dataset, by summing the chi-squared-map.
+        """
+        return fit_util.chi_squared_complex_with_mask_from(
+            chi_squared_map=self.chi_squared_map, mask=self.mask
+        )
+
+    @property
+    def noise_normalization(self) -> float:
+        """
+        Returns the noise-map normalization term of the noise-map, summing the noise_map value in every pixel as:
+
+        [Noise_Term] = sum(log(2*pi*[Noise]**2.0))
+        """
+        return fit_util.noise_normalization_complex_with_mask_from(
+            noise_map=self.noise_map, mask=self.mask
+        )
