@@ -21,10 +21,10 @@ class TestInterferometer:
         )
 
         interferometer = interferometer.modified_visibilities_from_visibilities(
-            visibilities=np.array([[2, 2]])
+            visibilities=np.array([2 + 2j])
         )
 
-        assert (interferometer.visibilities == np.array([[2, 2]])).all()
+        assert (interferometer.visibilities == np.array([[2 + 2j]])).all()
         assert interferometer.noise_map == 1
         assert interferometer.uv_wavelengths == 2
 
@@ -33,23 +33,39 @@ class TestInterferometer:
     ):
 
         interferometer = aa.Interferometer(
-            visibilities=aa.Visibilities(visibilities_1d=np.array([[1, 1]])),
-            noise_map=aa.VisibilitiesNoiseMap(visibilities_1d=np.array([[1, 5]])),
+            visibilities=aa.Visibilities(visibilities=np.array([1 + 1j, 1 + 1j])),
+            noise_map=aa.VisibilitiesNoiseMap(
+                visibilities=np.array([1 + 0.25j, 1 + 0.25j])
+            ),
             uv_wavelengths=2,
         )
 
         interferometer_capped = interferometer.signal_to_noise_limited_from(
-            signal_to_noise_limit=0.5
+            signal_to_noise_limit=2.0
         )
 
-        assert (interferometer_capped.visibilities == np.array([[1.0, 1.0]])).all()
+        assert (
+            interferometer_capped.visibilities == np.array([1.0 + 1.0j, 1.0 + 1.0j])
+        ).all()
+        assert (
+            interferometer_capped.noise_map == np.array([1.0 + 0.5j, 1.0 + 0.5j])
+        ).all()
+        assert (
+            interferometer_capped.signal_to_noise_map == np.array([1.0 + 2.0j])
+        ).all()
 
-        print(interferometer_capped.noise_map)
-
-        assert (interferometer_capped.noise_map == np.array([[2.0, 5.0]])).all()
+        interferometer_capped = interferometer.signal_to_noise_limited_from(
+            signal_to_noise_limit=0.25
+        )
 
         assert (
-            interferometer_capped.signal_to_noise_map == np.array([[0.5, 0.2]])
+            interferometer_capped.visibilities == np.array([1.0 + 1.0j, 1.0 + 1.0j])
+        ).all()
+        assert (
+            interferometer_capped.noise_map == np.array([4.0 + 4.0j, 4.0 + 4.0j])
+        ).all()
+        assert (
+            interferometer_capped.signal_to_noise_map == np.array([0.25 + 0.25j])
         ).all()
 
     def test__from_fits__all_files_in_one_fits__load_using_different_hdus(self):
@@ -63,10 +79,13 @@ class TestInterferometer:
             uv_wavelengths_hdu=2,
         )
 
-        assert (interferometer.visibilities.real == np.ones(3)).all()
-        assert (interferometer.visibilities.imag == np.ones(3)).all()
-        assert (interferometer.noise_map.real == 2.0 * np.ones(3)).all()
-        assert (interferometer.noise_map.imag == 2.0 * np.ones(3)).all()
+        assert (
+            interferometer.visibilities
+            == np.array([1.0 + 1.0j, 1.0 + 1.0j, 1.0 + 1.0j])
+        ).all()
+        assert (
+            interferometer.noise_map == np.array([2.0 + 2.0j, 2.0 + 2.0j, 2.0 + 2.0j])
+        ).all()
         assert (interferometer.uv_wavelengths[:, 0] == 3.0 * np.ones(3)).all()
         assert (interferometer.uv_wavelengths[:, 1] == 3.0 * np.ones(3)).all()
 
@@ -103,10 +122,13 @@ class TestInterferometer:
             uv_wavelengths_path=path.join(output_data_dir, "uv_wavelengths.fits"),
         )
 
-        assert (interferometer.visibilities.real == np.ones(3)).all()
-        assert (interferometer.visibilities.imag == 2.0 * np.ones(3)).all()
-        assert (interferometer.noise_map.real == 3.0 * np.ones((3,))).all()
-        assert (interferometer.noise_map.imag == 4.0 * np.ones((3,))).all()
+        assert (
+            interferometer.visibilities
+            == np.array([1.0 + 2.0j, 1.0 + 2.0j, 1.0 + 2.0j])
+        ).all()
+        assert (
+            interferometer.noise_map == np.array([3.0 + 4.0j, 3.0 + 4.0j, 3.0 + 4.0j])
+        ).all()
         assert (interferometer.uv_wavelengths[:, 0] == 5.0 * np.ones(3)).all()
         assert (interferometer.uv_wavelengths[:, 1] == 6.0 * np.ones(3)).all()
 
@@ -141,25 +163,25 @@ class TestSettingsMaskedInterferometer:
 
 class TestMaskedInterferometer:
     def test__masked_dataset(
-        self, interferometer_7, sub_mask_7x7, visibilities_7x2, noise_map_7x2
+        self, interferometer_7, sub_mask_7x7, visibilities_7, visibilities_noise_map_7
     ):
 
         masked_interferometer_7 = aa.MaskedInterferometer(
             interferometer=interferometer_7,
-            visibilities_mask=np.full(fill_value=False, shape=(7, 2)),
+            visibilities_mask=np.full(fill_value=False, shape=(7,)),
             real_space_mask=sub_mask_7x7,
         )
 
         assert (
             masked_interferometer_7.visibilities == interferometer_7.visibilities
         ).all()
-        assert (masked_interferometer_7.visibilities == visibilities_7x2).all()
+        assert (masked_interferometer_7.visibilities == visibilities_7).all()
 
-        assert (masked_interferometer_7.noise_map == noise_map_7x2).all()
+        assert (masked_interferometer_7.noise_map == visibilities_noise_map_7).all()
 
         assert (
             masked_interferometer_7.visibilities_mask
-            == np.full(fill_value=False, shape=(7, 2))
+            == np.full(fill_value=False, shape=(7,))
         ).all()
 
         assert (
@@ -207,7 +229,7 @@ class TestMaskedInterferometer:
             uv_wavelengths=3.0 * np.ones((19, 2)),
         )
 
-        visibilities_mask = np.full(fill_value=False, shape=(19, 2))
+        visibilities_mask = np.full(fill_value=False, shape=(19,))
 
         real_space_mask = aa.Mask2D.unmasked(
             shape_2d=(19, 19), pixel_scales=1.0, invert=True, sub_size=8
@@ -220,33 +242,39 @@ class TestMaskedInterferometer:
             real_space_mask=real_space_mask,
         )
 
-        assert (masked_interferometer_7.visibilities == np.ones((19, 2))).all()
-        assert (masked_interferometer_7.noise_map == 2.0 * np.ones((19, 2))).all()
+        assert (
+            masked_interferometer_7.visibilities == 1.0 + 1.0j * np.ones((19,))
+        ).all()
+        assert (masked_interferometer_7.noise_map == 2.0 + 2.0j * np.ones((19,))).all()
         assert (
             masked_interferometer_7.interferometer.uv_wavelengths
             == 3.0 * np.ones((19, 2))
         ).all()
 
     def test__modified_noise_map(
-        self, noise_map_7x2, interferometer_7, sub_mask_7x7, visibilities_mask_7x2
+        self,
+        visibilities_noise_map_7,
+        interferometer_7,
+        sub_mask_7x7,
+        visibilities_mask_7,
     ):
 
         masked_interferometer_7 = aa.MaskedInterferometer(
             interferometer=interferometer_7,
-            visibilities_mask=visibilities_mask_7x2,
+            visibilities_mask=visibilities_mask_7,
             real_space_mask=sub_mask_7x7,
             settings=aa.SettingsMaskedInterferometer(
                 transformer_class=aa.TransformerDFT
             ),
         )
 
-        noise_map_7x2[0, 0] = 10.0
+        visibilities_noise_map_7[0] = 10.0 + 20.0j
 
         masked_interferometer_7 = masked_interferometer_7.modify_noise_map(
-            noise_map=noise_map_7x2
+            noise_map=visibilities_noise_map_7
         )
 
-        assert masked_interferometer_7.noise_map[0, 0] == 10.0
+        assert masked_interferometer_7.noise_map[0] == 10.0 + 20.0j
 
 
 class TestSimulatorInterferometer:
@@ -317,7 +345,7 @@ class TestSimulatorInterferometer:
 
         assert interferometer.visibilities == pytest.approx(visibilities, 1.0e-4)
 
-        assert (interferometer.noise_map == 0.2 * np.ones((7, 2))).all()
+        assert (interferometer.noise_map == 0.2 + 0.2j * np.ones((7,))).all()
 
     def test__setup_with_noise(self, uv_wavelengths_7x2, transformer_7x7_7):
 
@@ -336,15 +364,8 @@ class TestSimulatorInterferometer:
 
         interferometer = simulator.from_image(image=image)
 
-        transformer = simulator.transformer_class(
-            uv_wavelengths=uv_wavelengths_7x2,
-            real_space_mask=aa.Mask2D.unmasked(
-                shape_2d=(3, 3), pixel_scales=image.pixel_scales
-            ),
+        assert interferometer.visibilities[0] == pytest.approx(
+            -0.005364 - 2.36682j, 1.0e-4
         )
 
-        assert interferometer.visibilities[0, :] == pytest.approx(
-            [-0.005364, -2.36682], 1.0e-4
-        )
-
-        assert (interferometer.noise_map == 0.1 * np.ones((7, 2))).all()
+        assert (interferometer.noise_map == 0.1 + 0.1j * np.ones((7,))).all()
