@@ -11,10 +11,7 @@ directory = path.dirname(path.realpath(__file__))
 @pytest.fixture(name="plot_path")
 def make_plot_path_setup():
     return path.join(
-        "{}".format(path.dirname(path.realpath(__file__))),
-        "files",
-        "plots",
-        "mapper",
+        "{}".format(path.dirname(path.realpath(__file__))), "files", "plots", "mapper"
     )
 
 
